@@ -435,7 +435,7 @@ def compute_alpha_metrics(data_df = None, core_tokens=['BTC', 'ETH'], extra_toke
         limited_dd_data_df = limited_dd_data_df[limited_dd_data_df.index <= '2021-07-01'].copy()
 
         dd_list = []
-        for me_underlying in [f'close_{ssj}' for ssj in ['BTC', 'AVAX']] + ['COMBO_STRAT']:
+        for me_underlying in [f'close_{ssj}' for ssj in ['BTC'] + extra_tokens  ] + ['COMBO_STRAT']:
             dd_display_name = 'drawdown ' + me_underlying.replace('close_', '')
             dd_list.append(dd_display_name)
             ### whole period drawdown
@@ -452,14 +452,20 @@ def compute_alpha_metrics(data_df = None, core_tokens=['BTC', 'ETH'], extra_toke
 
 
         if plot_html_save:
-            new_names = {'drawdown BTC': 'Bitcoin', 'drawdown AVAX': 'AVAX',
-                         'drawdown COMBO_STRAT': 'Absolute Return DeFi Strategy'}
+            dd_dic = {}
+            for me_under in extra_tokens:
+                dd_dic[f'drawdown {me_under}'] = me_under
+
+
+            new_names = {'drawdown BTC': 'Bitcoin', 'drawdown COMBO_STRAT': 'Absolute Return DeFi Strategy'}
+
+            new_names.update(dd_dic)
+
             dd_data_df = dd_data_df.rename(columns=new_names)
             fig = realtime_plotting_utility.plot_multiple_drawdowns(dd_data_df,
                                                                     list(new_names.values()))
             fig.show()
-            new_names = {'drawdown BTC': 'Bitcoin', 'drawdown AVAX': 'AVAX',
-                         'drawdown COMBO_STRAT': 'Absolute Return DeFi Strategy'}
+
             limited_dd_data_df = limited_dd_data_df.rename(columns=new_names)
             fig = realtime_plotting_utility.plot_multiple_drawdowns(limited_dd_data_df,
                                                                     list(new_names.values()))
@@ -668,13 +674,13 @@ def compute_alpha_metrics(data_df = None, core_tokens=['BTC', 'ETH'], extra_toke
 
 
         if write_excel_file:
-            writer = pd.ExcelWriter(local_root_directory + f'{moderating_factor}_{universe_literal}_weekly_ls_epochs_details_ls.xlsx',
+            writer = pd.ExcelWriter(local_root_directory + f'{universe_literal}_weekly_ls_epochs_details_ls.xlsx',
                                     engine='xlsxwriter')
             freq_aggregated_df.to_excel(writer, sheet_name='epoch')
             writer.save()
 
             writer = pd.ExcelWriter(
-                local_root_directory + f'{moderating_factor}_{universe_literal}_kpi_df_ls_strategy.xlsx',
+                local_root_directory + f'{universe_literal}_kpi_df_ls_strategy.xlsx',
                 engine='xlsxwriter')
             # whole_period_kpi_df.to_excel(writer, sheet_name=frequency)
             btd_kpis = btd_kpis.to_frame()
